# jange
[![Build Status](https://travis-ci.org/jangedoo/jange.svg?branch=master)](https://travis-ci.org/jangedoo/jange)
------
jange is an easy to use NLP library for Python. It is based on popular libraries like `pandas`, `scikit-learn`, `spacy`, `plotly` and others.

# Installation
```
pip install jange
```

## From source
This project uses poetry to manage dependencies. If you don't already have poetry installed then go to https://python-poetry.org/docs/#installation for instructions on how to install it for your OS.

Once poetry is installed, from the root directory of this project, run `poetry install`. It will create a virtual environment for this project and install the necessary dependencies (including dev dependencies).
